@@ -1,8 +1,8 @@
 logLik.SemiParBIVProbit <- function (object, ...){
 
-    if (length(list(...))) warning("eobjecttra arguments discarded")
+    if (length(list(...))) warning("extra arguments discarded")
     
-    lk  <- object$logLik
+    lk <- object$logLik
     
     attr(lk, "nobs") <- object$n
     attr(lk, "df") <- object$t.edf
