@@ -34,8 +34,8 @@ print.SemiParBIVProbit <- function(x, ...){
     if(x$margins[2]=="logit")                                   m2l <- "logit"
     if(x$margins[2]=="cloglog")                                 m2l <- "cloglog"
     if(x$margins[2]=="cauchit")                                 m2l <- "cauchit"   
-    if(x$margins[2] %in% c("N","GU","rGU","LO") )               m2l <- "identity"
-    if(x$margins[2] %in% c("LN","WEI","iG","GA","DAGUM","SM") ) m2l <- "log"   
+    if(x$margins[2] %in% c("N","GU","rGU","LO","GAi") )               m2l <- "identity"
+    if(x$margins[2] %in% c("LN","WEI","iG","GA","DAGUM","SM","FISK") ) m2l <- "log"   
     if(x$margins[2] %in% c("BE") )                              m2l <- "qlogis"   
     
       cat(main.t,cop) 
@@ -50,10 +50,12 @@ print.SemiParBIVProbit <- function(x, ...){
       if(x$margins[2]=="LN")     cat("\nMARGIN 2: log-normal") 
       if(x$margins[2]=="WEI")    cat("\nMARGIN 2: Weibull") 
       if(x$margins[2]=="iG")     cat("\nMARGIN 2: inverse Gaussian") 
-      if(x$margins[2]=="GA")     cat("\nMARGIN 2: gamma")   
+      if(x$margins[2]%in%c("GA","GAi"))     cat("\nMARGIN 2: gamma")   
       if(x$margins[2]=="BE")     cat("\nMARGIN 2: beta")    
       if(x$margins[2]=="DAGUM")  cat("\nMARGIN 2: Dagum")
       if(x$margins[2]=="SM")     cat("\nMARGIN 2: Singh-Maddala") 
+      if(x$margins[2]=="FISK")     cat("\nMARGIN 2: Fisk") 
+      
     
     
     
@@ -125,7 +127,7 @@ print.SemiParBIVProbit <- function(x, ...){
   
   
   
-  cont2par <- c("N","GU","rGU","LO","LN","WEI","iG","GA","BE")  
+  cont2par <- c("N","GU","rGU","LO","LN","WEI","iG","GA","GAi","BE","FISK")  
   cont3par <- c("DAGUM","SM")  
   
   
@@ -134,9 +136,9 @@ print.SemiParBIVProbit <- function(x, ...){
   if(x$Model %in% c("B","BPO") && x$margins[2] %in% bin.link) cat("n = ",x$n,cp,format(as.p, digits=3),"  total edf = ",format(x$t.edf, digits=3),"\n\n", sep="")
   if(x$Model == "BPO0")                                   cat("n = ",x$n,"  total edf = ",format(x$t.edf, digits=3),"\n\n", sep="")
 
-  if(x$Model=="BSS")                                      cat("n = ",x$n,"  n.sel = ",x$n.sel,cp,format(as.p, digits=3),"  total edf = ",format(x$t.edf, digits=3),"\n\n", sep="")
+  if(x$Model=="BSS")                                      cat("n = ",x$n,"  n.sel = ",x$n.sel,cp,format(as.p, digits=3),"\ntotal edf = ",format(x$t.edf, digits=3),"\n\n", sep="")
   
-  if(x$Model=="B" && x$margins[2] %in% cont2par ) cat("n = ",x$n,"  sigma2 = ",x$sigma2.a, cp, format(as.p, digits=3),"  total edf = ",format(x$t.edf, digits=3),"\n\n", sep="")
+  if(x$Model=="B" && x$margins[2] %in% cont2par ) cat("n = ",x$n,"  sigma2 = ",x$sigma2.a, cp, format(as.p, digits=3),"\ntotal edf = ",format(x$t.edf, digits=3),"\n\n", sep="")
 
   if(x$Model=="B" && x$margins[2] %in% cont3par ) cat("n = ",x$n,"  sigma2 = ",x$sigma2.a, "  nu = ",x$nu.a, "\ntheta = ", format(as.p, digits=3),"  total edf = ",format(x$t.edf, digits=3),"\n\n", sep="")
 
